==> estateplat-common-1.2.3-20180123.013116-21-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfMmhtCjjgfkfs.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;


/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "fcjy_clf_mmht_cjjgfkfs")
public class FcjyClfMmhtCjjgfkfs implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String sfdl;//是否通过房地产经纪机构居间或者代理
    private Double mmfjk;//买卖房价款
    private String fkfs;//付款方式
    private Double ycxfkjgje;//一次性付款监管金额
    private String ycxfkyh;//一次性付款银行
    private String ycxfkhm;//一次性付款户名
    private String ycxfkzh;//一次性付款账号
    private Double yhdksf;//银行贷款首付
    private Double yhdkdkje;//银行贷款贷款金额
    private String yhdkdkzl;//银行贷款贷款种类
    private String grzhkhyh;//个人账户开户银行
    private String grzhhm;//个人账户户名
    private String grzhzh;//个人账户账号
    private String sfzjjg;//是否资金监管
    private Double zjjgje;//资金监管金额
    private Double yffjk;//预付房价款
    private Date fkjzrq;//付款截止日期

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getSfdl() {
        return sfdl;
    }

    public void setSfdl(String sfdl) {
        this.sfdl = sfdl;
    }

    public Double getMmfjk() {
        return mmfjk;
    }

    public void setMmfjk(Double mmfjk) {
        this.mmfjk = mmfjk;
    }

    public String getFkfs() {
        return fkfs;
    }

    public void setFkfs(String fkfs) {
        this.fkfs = fkfs;
    }

    public Double getYcxfkjgje() {
        return ycxfkjgje;
    }

    public void setYcxfkjgje(Double ycxfkjgje) {
        this.ycxfkjgje = ycxfkjgje;
    }

    public String getYcxfkyh() {
        return ycxfkyh;
    }

    public void setYcxfkyh(String ycxfkyh) {
        this.ycxfkyh = ycxfkyh;
    }

    public String getYcxfkhm() {
        return ycxfkhm;
    }

    public void setYcxfkhm(String ycxfkhm) {
        this.ycxfkhm = ycxfkhm;
    }

    public String getYcxfkzh() {
        return ycxfkzh;
    }

    public void setYcxfkzh(String ycxfkzh) {
        this.ycxfkzh = ycxfkzh;
    }

    public Double getYhdksf() {
        return yhdksf;
    }

    public void setYhdksf(Double yhdksf) {
        this.yhdksf = yhdksf;
    }

    public Double getYhdkdkje() {
        return yhdkdkje;
    }

    public void setYhdkdkje(Double yhdkdkje) {
        this.yhdkdkje = yhdkdkje;
    }

    public String getYhdkdkzl() {
        return yhdkdkzl;
    }

    public void setYhdkdkzl(String yhdkdkzl) {
        this.yhdkdkzl = yhdkdkzl;
    }

    public String getGrzhkhyh() {
        return grzhkhyh;
    }

    public void setGrzhkhyh(String grzhkhyh) {
        this.grzhkhyh = grzhkhyh;
    }

    public String getGrzhhm() {
        return grzhhm;
    }

    public void setGrzhhm(String grzhhm) {
        this.grzhhm = grzhhm;
    }

    public String getGrzhzh() {
        return grzhzh;
    }

    public void setGrzhzh(String grzhzh) {
        this.grzhzh = grzhzh;
    }

    public String getSfzjjg() {
        return sfzjjg;
    }

    public void setSfzjjg(String sfzjjg) {
        this.sfzjjg = sfzjjg;
    }

    public Double getZjjgje() {
        return zjjgje;
    }

    public void setZjjgje(Double zjjgje) {
        this.zjjgje = zjjgje;
    }

    public Double getYffjk() {
        return yffjk;
    }

    public void setYffjk(Double yffjk) {
        this.yffjk = yffjk;
    }

    public Date getFkjzrq() {
        return fkjzrq;
    }

    public void setFkjzrq(Date fkjzrq) {
        this.fkjzrq = fkjzrq;
    }
}

==> estateplat-common-1.2.3-20180612.081212-112-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfMmhtCjjgfkfs.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;


/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "fcjy_clf_mmht_cjjgfkfs")
public class FcjyClfMmhtCjjgfkfs implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String sfdl;//是否通过房地产经纪机构居间或者代理
    private Double mmfjk;//买卖房价款
    private String fkfs;//付款方式
    private Double ycxfkjgje;//一次性付款监管金额
    private String ycxfkyh;//一次性付款银行
    private String ycxfkhm;//一次性付款户名
    private String ycxfkzh;//一次性付款账号
    private Double yhdksf;//银行贷款首付
    private Double yhdkdkje;//银行贷款贷款金额
    private String yhdkdkzl;//银行贷款贷款种类
    private String grzhkhyh;//个人账户开户银行
    private String grzhhm;//个人账户户名
    private String grzhzh;//个人账户账号
    private String sfzjjg;//是否资金监管
    private Double zjjgje;//资金监管金额
    private Double yffjk;//预付房价款
    private Date fkjzrq;//付款截止日期
    private Date ycxfkrq;//一次性付款日期
    private Double fqfkdj;//分期付款定金
    private Double fqfksf;//分期付款首付
    private Double fqfkyk;//分期付款余款
    private Date djfkrq;//定金付款日期
    private Date sffkrq;//首付付款日期
    private Date ykfkrq;//余款付款日期
    private String qtsm;//其他说明

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getSfdl() {
        return sfdl;
    }

    public void setSfdl(String sfdl) {
        this.sfdl = sfdl;
    }

    public Double getMmfjk() {
        return mmfjk;
    }

    public void setMmfjk(Double mmfjk) {
        this.mmfjk = mmfjk;
    }

    public String getFkfs() {
        return fkfs;
    }

    public void setFkfs(String fkfs) {
        this.fkfs = fkfs;
    }

    public Double getYcxfkjgje() {
        return ycxfkjgje;
    }

    public void setYcxfkjgje(Double ycxfkjgje) {
        this.ycxfkjgje = ycxfkjgje;
    }

    public String getYcxfkyh() {
        return ycxfkyh;
    }

    public void setYcxfkyh(String ycxfkyh) {
        this.ycxfkyh = ycxfkyh;
    }

    public String getYcxfkhm() {
        return ycxfkhm;
    }

    public void setYcxfkhm(String ycxfkhm) {
        this.ycxfkhm = ycxfkhm;
    }

    public String getYcxfkzh() {
        return ycxfkzh;
    }

    public void setYcxfkzh(String ycxfkzh) {
        this.ycxfkzh = ycxfkzh;
    }

    public Double getYhdksf() {
        return yhdksf;
    }

    public void setYhdksf(Double yhdksf) {
        this.yhdksf = yhdksf;
    }

    public Double getYhdkdkje() {
        return yhdkdkje;
    }

    public void setYhdkdkje(Double yhdkdkje) {
        this.yhdkdkje = yhdkdkje;
    }

    public String getYhdkdkzl() {
        return yhdkdkzl;
    }

    public void setYhdkdkzl(String yhdkdkzl) {
        this.yhdkdkzl = yhdkdkzl;
    }

    public String getGrzhkhyh() {
        return grzhkhyh;
    }

    public void setGrzhkhyh(String grzhkhyh) {
        this.grzhkhyh = grzhkhyh;
    }

    public String getGrzhhm() {
        return grzhhm;
    }

    public void setGrzhhm(String grzhhm) {
        this.grzhhm = grzhhm;
    }

    public String getGrzhzh() {
        return grzhzh;
    }

    public void setGrzhzh(String grzhzh) {
        this.grzhzh = grzhzh;
    }

    public String getSfzjjg() {
        return sfzjjg;
    }

    public void setSfzjjg(String sfzjjg) {
        this.sfzjjg = sfzjjg;
    }

    public Double getZjjgje() {
        return zjjgje;
    }

    public void setZjjgje(Double zjjgje) {
        this.zjjgje = zjjgje;
    }

    public Double getYffjk() {
        return yffjk;
    }

    public void setYffjk(Double yffjk) {
        this.yffjk = yffjk;
    }

    public Date getFkjzrq() {
        return fkjzrq;
    }

    public void setFkjzrq(Date fkjzrq) {
        this.fkjzrq = fkjzrq;
    }

    public Date getYcxfkrq() {
        return ycxfkrq;
    }

    public void setYcxfkrq(Date ycxfkrq) {
        this.ycxfkrq = ycxfkrq;
    }

    public Double getFqfkdj() {
        return fqfkdj;
    }

    public void setFqfkdj(Double fqfkdj) {
        this.fqfkdj = fqfkdj;
    }

    public Double getFqfksf() {
        return fqfksf;
    }

    public void setFqfksf(Double fqfksf) {
        this.fqfksf = fqfksf;
    }

    public Double getFqfkyk() {
        return fqfkyk;
    }

    public void setFqfkyk(Double fqfkyk) {
        this.fqfkyk = fqfkyk;
    }

    public Date getDjfkrq() {
        return djfkrq;
    }

    public void setDjfkrq(Date djfkrq) {
        this.djfkrq = djfkrq;
    }

    public Date getSffkrq() {
        return sffkrq;
    }

    public void setSffkrq(Date sffkrq) {
        this.sffkrq = sffkrq;
    }

    public Date getYkfkrq() {
        return ykfkrq;
    }

    public void setYkfkrq(Date ykfkrq) {
        this.ykfkrq = ykfkrq;
    }

    public String getQtsm() {
        return qtsm;
    }

    public void setQtsm(String qtsm) {
        this.qtsm = qtsm;
    }
}
